# memedict

Knowyourmeme.com definitions scraper

## Install

    pip install memedict
    
## Usage

    >>> from memedict import search
    >>> search('base belong to us')
    u'"All Your Base Are Belong to Us" is a popular engrish catchphrase that grew popular across the internet as early as in 1998. An awkward translation of "all of your bases are now under our control", the quote originally appeared in the opening dialogue of Zero Wing, a 16-bit shoot\'em up game released in 1989. Marked by poor grammar, the "All Your Base" phrase and the dialogue scene went viral on popular discussion forums in 2000, spawning thousands of image macros and flash animations featuring the slogan both on the web and in real life.'

